@@ -1,3 +1,4 @@
+import inspect
 from .task import Task
 
 
@@ -10,10 +11,15 @@ def task(func):
             f'found {func.__name__}')
 
     class FuncTask(Task):
-        run = func
+        async def run(self, **inputs):
+            if inspect.iscoroutinefunction(func):
+                return await func(**inputs)
+            else:
+                return func(**inputs)
 
     # copy name & module
     FuncTask.__name__ = func.__name__
     FuncTask.__module__ = func.__module__
+    FuncTask.__wraps__ = func
 
     return FuncTask
